# -*- coding: utf-8 -*-

#1a) In un file "GenBank" sono specificate porzioni particolari del record 
# che corrispondono ad entità con un particolare significato o funzione: esse
# sono note come "features" e in Biopython sono supportate dalla classe
# Bio.SeqFeature, con attributi per le relative informazioni. 
# Un oggetto SeqRecord ha l'attributo "features" che è la lista con tutte 
# le relative features rappresentate come istanze di SeqFeature.
# Scrivere una funzione extract_feat_seqs(gbfile, feat_type) che, dato un 
# file GenBank e un tipo di feature (specificato come stringa), restituisca
# la lista di tutti gli oggetti Seq corrispondenti alle feature del tipo 
# dato. Si consulti la documentazione di Biopython prima di procedere 
# all'implementazione, per capire come ottenere tali oggetti Seq a partire 
# dalle SeqFeature (sez. 4.3.1 e 4.3.3 del Tutorial).


from Bio import SeqIO

def extract_feat_seqs(gbfile, feat_type):
    
    record = SeqIO.read(gbfile, "genbank") #get the record from file
    
    whole_seq = record.seq  #this refers the complete sequence as a Seq object
    
    #now: iterate over all the features (attribute "features" of a SeqRecord),
    #consider only those features whose type is feat_type (in input),
    #and for each of them extract the relative Seq object out of the complete
    #sequence (using the "extract" method).
    
    return [feat.extract(whole_seq) for feat in record.features 
            if feat.type == feat_type]
